# Introduction

[Avulto][] is a Python library used to interact with BYOND codebases; primarily
Space Station 13 codebases. It is built on top of the Rust library
[SpacemanDMM][], and is fast and versatile.

[Avulto]: https://pypi.org/project/avulto/
[SpacemanDMM]: https://github.com/SpaceManiac/SpacemanDMM/
